# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetLkeVersionsResult',
    'AwaitableGetLkeVersionsResult',
    'get_lke_versions',
]

@pulumi.output_type
class GetLkeVersionsResult:
    """
    A collection of values returned by getLkeVersions.
    """
    def __init__(__self__, id=None, versions=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if versions and not isinstance(versions, list):
            raise TypeError("Expected argument 'versions' to be a list")
        pulumi.set(__self__, "versions", versions)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The Kubernetes version numbers available for deployment to a Kubernetes cluster in the format of [major].[minor], and the latest supported patch version.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def versions(self) -> Sequence['outputs.GetLkeVersionsVersionResult']:
        return pulumi.get(self, "versions")


class AwaitableGetLkeVersionsResult(GetLkeVersionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLkeVersionsResult(
            id=self.id,
            versions=self.versions)


def get_lke_versions(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLkeVersionsResult:
    """
    Provides details about the Kubernetes versions available for deployment to a Kubernetes cluster.

    ## Example Usage

    The following example shows how one might use this data source to access information about a Linode LKE Version.

    ```python
    import pulumi
    import pulumi_linode as linode

    example = linode.get_lke_versions()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('linode:index/getLkeVersions:getLkeVersions', __args__, opts=opts, typ=GetLkeVersionsResult).value

    return AwaitableGetLkeVersionsResult(
        id=pulumi.get(__ret__, 'id'),
        versions=pulumi.get(__ret__, 'versions'))
